"""Command-line interface."""

import argparse
import logging
import os

import colorlog

from camera_multi_tester.modules.networkhandler import NetworkMonitor
from camera_multi_tester.modules.uarthandler import CMTMonitor

from . import __version__


def _logger_level(args: argparse.Namespace) -> None:
    if args.debug:
        logging.getLogger().setLevel(logging.DEBUG)
    return


def _logger_conf(args: argparse.Namespace) -> None:
    """Setup the logging environment."""
    log = logging.getLogger()
    log.setLevel(logging.INFO)
    format_str = "%(asctime)s - %(levelname)-8s - %(message)s"
    date_format = "%Y-%m-%d %H:%M:%S"
    formatter = logging.Formatter(format_str, date_format)
    if os.isatty(2):
        cformat = "%(log_color)s" + format_str
        colors = {
            "DEBUG": "reset",
            "INFO": "bold_black",
            "WARNING": "bold_yellow",
            "ERROR": "bold_red",
            "CRITICAL": "bold_red",
        }
        formatter = colorlog.ColoredFormatter(cformat, date_format, log_colors=colors)
    stream_handler = logging.StreamHandler()
    stream_handler.setFormatter(formatter)
    stream_handler = logging.StreamHandler()
    stream_handler.setFormatter(formatter)
    log.addHandler(stream_handler)
    log.setLevel(logging.INFO)
    _logger_level(args)
    return


def _parser() -> argparse.ArgumentParser:
    parser = argparse.ArgumentParser(description="Auto Flash Release Tool")
    parser.add_argument(
        "-d",
        "--debug",
        help="enable debug output",
        action="store_true",
    )
    parser.add_argument(
        "-v",
        "--version",
        help="%(prog)s version",
        action="version",
        version=f"%(prog)s {__version__}",
    )
    return parser


def cmt() -> None:
    """Camera Multi Tester initializer."""
    uartmon = CMTMonitor()
    netwmon = NetworkMonitor()
    uartmon.set_netwmon(netwmon)
    return


def main() -> None:
    """Camera Multi Tester."""
    p = _parser()
    args, _ = p.parse_known_args()
    _logger_conf(args)
    cmt()
    logging.info("Camera Multi Tester")
    return


if __name__ == "__main__":
    main()  # pragma: no cover
