"""Network Monitor."""

import logging
import threading
import time

import netifaces as ni  # type: ignore


class NetworkMonitor:
    """Network Monitor."""

    def __init__(self) -> None:
        """The NetworkMonitor constructor."""
        self.netwdevs: dict[str, dict[str, str]] = {}
        t = threading.Thread(target=self.netwd, args=([]))
        t.start()
        return

    def get_netwdevs(self) -> dict[str, dict[str, str]]:
        """Returns network devices dictionary."""
        return self.netwdevs

    def netwd(self) -> None:
        """Network daemon to monitor network devices."""
        netwdevs: dict[str, dict[str, str]] = {}
        while True:
            time.sleep(0.4)
            self.netwdevs = self._get_netdevs()
            if netwdevs != self.netwdevs:
                logging.debug(f"Network: {self.netwdevs}")
                netwdevs = self.netwdevs

    def _get_netdevs(self) -> dict[str, dict[str, str]]:
        """Get network devices dictionary."""
        dev: dict[str, dict[str, str]] = {}
        for d in ni.interfaces():
            # Only 'eth.*' network devices
            if "eth" not in d:
                continue
            # Skip net devices with no IP
            if len(ni.ifaddresses(d)) <= 1:
                continue
            if ni.AF_INET not in ni.ifaddresses(d).keys():
                continue
            ip = ni.ifaddresses(d)[ni.AF_INET][0]["addr"]
            mac = ni.ifaddresses(d)[ni.AF_LINK][0]["addr"]
            dev.update({d: {"ip": ip, "mac": mac}})
        return dev
